@@ -9,8 +9,7 @@ pub const INSTRUCTION_CREATE_AIRDROP_ACCOUNT:u8=6;
 pub const INSTRUCTION_ADD_USER_TO_AIRDROP_ACCOUNT:u8=7;
 pub const INSTRUCTION_SERUM_SWAP:u8=8;
 pub const INSTRUCTION_CLOSE_TURING_MASHINE:u8=9;
-//pub const INSTRUCTION_CLOSE_TURING_TRIGGUER:u8=9;
-pub const INSTRUCTION_UPDATE_STATE_PPU:u8=10;
+pub const INSTRUCTION_UPDATE_STATE_TURING_MASHINE:u8=10;
 pub const INSTRUCTION_UPDATE_AMOUNT_PPU:u8=11;
 pub const INSTRUCTION_STAKE_LP_TOKEN:u8=12;
 pub const INSTRUCTION_UPDATE_SPLU_PPU_STABEL_COINS:u8=13;
